@@ -8,7 +8,6 @@ from django.utils.translation import ugettext as _
 from django.core.exceptions import ImproperlyConfigured
 
 import re
-import decimal
 from datetime import datetime
 try:
     from dateutil import parser as date_parser
@@ -45,10 +44,6 @@ class JSONDecoder(json.JSONDecoder):
                 if self._is_recursive(value):
                     obj[key] = self.decode(value, recurse=True)
         elif isinstance(obj, basestring):
-            try:
-                return decimal.Decimal(obj)
-            except decimal.InvalidOperation:
-                pass
             if TIME_RE.match(obj):
                 try:
                     return date_parser.parse(obj).time()
